package com.qmth.distributed.print.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.distributed.print.business.service.OpenApiService;
import com.qmth.teachcloud.common.contant.SystemConstant;
import com.qmth.teachcloud.common.entity.BasicSchool;
import com.qmth.teachcloud.common.util.AuthThirdUtil;
import com.qmth.teachcloud.common.util.Result;
import com.qmth.teachcloud.common.util.ResultUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.constraints.Min;

/**
 * <p>
 * 知学知考开放接口前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-04-26
 */
@Api(tags = "知学知考开放接口Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.open}")
@Validated
public class OpenApiController {
    private static final Logger log = LoggerFactory.getLogger(OpenApiController.class);

    @Resource
    private OpenApiService openApiService;

    /**
     * 试卷基础配置查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷基础配置查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷基础配置查询", response = Object.class)})
    @PostMapping("/paper_config")
    @Aac(auth = BOOL.FALSE)
    public Result paperConfig(@RequestParam String thirdExamId,
                              @RequestParam String gradeCourseCode) {
        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(openApiService.getPaperConfig(basicSchool, thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷考察点查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷考察点查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷考察点查询", response = Object.class)})
    @PostMapping("/paper_dimension")
    @Aac(auth = BOOL.FALSE)
    public Result paperDimension(@RequestParam String thirdExamId,
                                 @RequestParam String gradeCourseCode) {
        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(openApiService.getPaperDimension(basicSchool, thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷蓝图查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷蓝图查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷蓝图查询", response = Object.class)})
    @PostMapping("/paper_structure")
    @Aac(auth = BOOL.FALSE)
    public Result paperStructure(@RequestParam String thirdExamId,
                                 @RequestParam String gradeCourseCode) {
        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(openApiService.getPaperStructure(basicSchool, thirdExamId, gradeCourseCode));
    }

    /**
     * 试卷评价模型查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "试卷评价模型查询")
    @ApiResponses({@ApiResponse(code = 200, message = "试卷评价模型查询", response = Object.class)})
    @PostMapping("/paper_evaluation")
    @Aac(auth = BOOL.FALSE)
    public Result paperEvaluation(@RequestParam String thirdExamId,
                                  @RequestParam String gradeCourseCode) {
        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(openApiService.getPaperEvaluation(basicSchool, thirdExamId, gradeCourseCode));
    }

    /**
     * 考生成绩查询
     *
     * @param thirdExamId     第三方考试id
     * @param gradeCourseCode 第三方课程编号
     */
    @ApiOperation(value = "考生成绩查询")
    @ApiResponses({@ApiResponse(code = 200, message = "考生成绩查询", response = Object.class)})
    @PostMapping("/exam_student_score")
    @Aac(auth = BOOL.FALSE)
    public Result examStudentScore(@RequestParam String thirdExamId,
                                   @RequestParam String gradeCourseCode,
                                   @RequestParam(defaultValue = "1") @Min(SystemConstant.PAGE_NUMBER_MIN) Integer pageNumber,
                                   @RequestParam(defaultValue = "10") @Min(SystemConstant.PAGE_SIZE_MIN) Integer pageSize) {
        BasicSchool basicSchool = AuthThirdUtil.hasPermission();
        return ResultUtil.ok(openApiService.listExamStudentScore(basicSchool, thirdExamId, gradeCourseCode, pageNumber, pageSize));
    }
}
